@@ -9,4 +9,4 @@ my (@num_items, @char_items);
 @num_items  = qw(1 2 3 5 6 7 9 12 14 19 21);
 @char_items = qw(abcdefgh bc def ghij klm pqrstu vwxyz);
 
-print median( \@num_items ),"\n";
+print median( @num_items ),"\n";
